==> egg-user-service-1.0.0-sources.jar: com/bxm/egg/user/warmlevel/impl/handler/UserPostAuditActionHandler.java <==
package com.bxm.egg.user.warmlevel.impl.handler;

import com.bxm.egg.user.constant.RedisConfig;
import com.bxm.egg.user.enums.WarmRuleEnum;
import com.bxm.egg.user.warmlevel.impl.context.WarmActionContext;
import com.bxm.egg.user.warmlevel.impl.rule.PostAuditSuccessRule;
import com.bxm.egg.user.warmlevel.impl.rule.WarmRule;
import com.bxm.newidea.component.redis.KeyGenerator;
import com.bxm.newidea.component.redis.RedisStringAdapter;
import com.bxm.newidea.component.tools.DateUtils;
import com.google.common.collect.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;

/**
 * 用户贴子被审核通过温暖值发放
 *
 * @author lowi
 * @date 2021/03/03 10:46
 */
@Component
public class UserPostAuditActionHandler extends AbstractWarmActionHandler {

    @Autowired
    private RedisStringAdapter redisStringAdapter;

    @Override
    protected void execAction(WarmActionContext context) {
        //获取此规则需要更改的温暖值
        context.setWarmRuleDetail(getWarmRule(context.getAction().name()));
    }

    @Override
    protected void afterPost(WarmActionContext context) {
        KeyGenerator keyGenerator = RedisConfig.USER_AUDIT_POST_WARM.copy().appendKey(DateUtils.formatDate(new Date())).appendKey(context.getUserId());
        redisStringAdapter.increment(keyGenerator, 1);
        redisStringAdapter.expire(keyGenerator, 2 * 24 * 60 * 60);
    }

    @Override
    public WarmRuleEnum support() {
        return WarmRuleEnum.POST_AUDIT_PASS;
    }

    @Override
    public Class<? extends WarmRule> bindRules() {
        return PostAuditSuccessRule.class;
    }
}

==> egg-user-service-2.4.0-sources.jar: com/bxm/egg/user/warmlevel/impl/handler/UserPostAuditActionHandler.java <==
package com.bxm.egg.user.warmlevel.impl.handler;

import com.bxm.egg.user.constant.RedisConfig;
import com.bxm.egg.user.facade.enums.WarmRuleEnum;
import com.bxm.egg.user.warmlevel.impl.context.WarmActionContext;
import com.bxm.egg.user.warmlevel.impl.rule.PostAuditSuccessRule;
import com.bxm.egg.user.warmlevel.impl.rule.WarmRule;
import com.bxm.newidea.component.redis.KeyGenerator;
import com.bxm.newidea.component.redis.RedisStringAdapter;
import com.bxm.newidea.component.tools.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;

/**
 * 用户贴子被审核通过温暖值发放
 *
 * @author lowi
 * @date 2021/03/03 10:46
 */
@Component
public class UserPostAuditActionHandler extends AbstractWarmActionHandler {

    @Autowired
    private RedisStringAdapter redisStringAdapter;

    @Override
    protected void execAction(WarmActionContext context) {
        //获取此规则需要更改的温暖值
        context.setWarmRuleDetail(getWarmRule(context.getAction().name()));
    }

    @Override
    protected void afterPost(WarmActionContext context) {
        KeyGenerator keyGenerator = RedisConfig.USER_AUDIT_POST_WARM.copy().appendKey(DateUtils.formatDate(new Date())).appendKey(context.getUserId());
        redisStringAdapter.increment(keyGenerator, 1);
        redisStringAdapter.expire(keyGenerator, 2 * 24 * 60 * 60);
    }

    @Override
    public WarmRuleEnum support() {
        return WarmRuleEnum.POST_AUDIT_PASS;
    }

    @Override
    public Class<? extends WarmRule> bindRules() {
        return PostAuditSuccessRule.class;
    }
}
